DoubleExtension extension

on

Methods

formatAmountFromDouble(dynamic scale) int

Available on double, provided by the DoubleExtension extension

Converts the double into an integer representation, scaled by scale.
parseDoubleIntoAmount({int decimals = 2, String decimalSeparator = ",", String thousandsSeparator = " "}) String

Available on double, provided by the DoubleExtension extension

Formats the double into a human-readable amount with decimals decimals, using a comma (,) as decimal separator and spaces ( ) as thousands separators.