getDayFromShortDate method
Returns the day part from a short date string (dd/MM).
Implementation
int getDayFromShortDate() {
return int.parse(split('/')[0]);
}
Returns the day part from a short date string (dd/MM).
int getDayFromShortDate() {
return int.parse(split('/')[0]);
}