getMonthFromShortDate method
Returns the month part from a short date string (dd/MM).
Implementation
int getMonthFromShortDate() {
return int.parse(split('/')[1]);
}
Returns the month part from a short date string (dd/MM).
int getMonthFromShortDate() {
return int.parse(split('/')[1]);
}