ScreenSizeConstants class
this class is used to setup screen size related variables package's users can overide them in his main file
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- LARGE_LAYOUT_BREAKPOINT ↔ int
-
getter/setter pair
- MOBILE_LANDSCAPE_BREAKPOINT ↔ int
-
getter/setter pair
- MOBILE_PORTRAIT_BREAKPOINT ↔ int
-
getter/setter pair
- SMALL_LAYOUT_BREAKPOINT ↔ int
-
getter/setter pair
- TABLET_LANDSCAPE_BREAKPOINT ↔ int
-
getter/setter pair
- TABLET_PORTRAIT_BREAKPOINT ↔ int
-
getter/setter pair