StringExtension extension
- on
Methods
-
capitalize(
) → String -
Available on String, provided by the StringExtension extension
Capitalizes the first letter of the string. -
charCodeBetween(
[int start = 0, int? length]) → double? -
Available on String, provided by the StringExtension extension
-
formatAmount(
{String? separator, String? decimal}) → String -
Available on String, provided by the StringExtension extension
-
formatInputToDateTime(
{String? specificFormat}) → DateTime -
Available on String, provided by the StringExtension extension
Parses the string into a DateTime using a custom format. -
formatISOToDateTime(
) → DateTime -
Available on String, provided by the StringExtension extension
Converts an ISO string to DateTime, ignoring timezone. -
formatPhone(
) → String -
Available on String, provided by the StringExtension extension
Formats a French phone number string (10 digits) with spaces every 2 digits. -
formatShortInputToDateTime(
{String? specificFormat}) → DateTime -
Available on String, provided by the StringExtension extension
Parses a short format date string into DateTime. -
formatStringToIsoDate(
) → DateTime -
Available on String, provided by the StringExtension extension
Parses a date string in the formatdd/MM/yyyyand returns a DateTime object. -
getDayFromShortDate(
) → int -
Available on String, provided by the StringExtension extension
Returns the day part from a short date string (dd/MM). -
getMonthFromShortDate(
) → int -
Available on String, provided by the StringExtension extension
Returns the month part from a short date string (dd/MM). -
getYearFromShortDate(
) → int -
Available on String, provided by the StringExtension extension
-
parseInputToDouble(
) → double -
Available on String, provided by the StringExtension extension
Parses the string into a double, converting ',' to '.' and removing spaces. -
snakeToCamel(
) → String -
Available on String, provided by the StringExtension extension
Converts a snake_case string to camelCase. -
tryParseInputToDouble(
) → double? -
Available on String, provided by the StringExtension extension
Attempts to parse the string into a double, returnsnullif parsing fails.